@@ -8,6 +8,7 @@ log = logging.getLogger(__name__)
 
 
 class _Req:
+
     def __init__(self, method: str, route: str, params: Dict):
         self.method = method
         self.route = route
@@ -15,7 +16,9 @@ class _Req:
 
 
 def req(method: str, **http_fields):
+
     def _method(func: Callable):
+
         @functools.wraps(func)
         def req_maker(*args, **kwargs) -> _Req:
             route = re.sub(r'(?<!^)(?=[A-Z])', '-', func.__qualname__).lower().replace('.', '/')
@@ -40,54 +43,46 @@ class Guild:
 
     @staticmethod
     @req('GET')
-    def list(
-    ):
+    def list():
         ...
 
     @staticmethod
     @req('GET')
-    def view(
-            guild_id
-    ):
+    def view(guild_id):
         ...
 
     @staticmethod
     @req('GET')
     def userList(
-            guild_id,
-            channel_id,
-            search,
-            role_id,
-            mobile_verified,
-            active_time,
-            joined_at,
-            page,
-            page_size,
+        guild_id,
+        channel_id,
+        search,
+        role_id,
+        mobile_verified,
+        active_time,
+        joined_at,
+        page,
+        page_size,
     ):
         ...
 
     @staticmethod
     @req('POST')
     def nickname(
-            guild_id,
-            nickname,
-            user_id,
+        guild_id,
+        nickname,
+        user_id,
     ):
         ...
 
     @staticmethod
     @req('POST')
-    def leave(
-            guild_id
-    ):
+    def leave(guild_id):
         ...
 
     @staticmethod
     @req('POST')
-    def kickout(
-            guild_id,
-            target_id
-    ):
+    def kickout(guild_id, target_id):
         ...
 
 
@@ -95,27 +90,24 @@ class GuildMute:
 
     @staticmethod
     @req('GET')
-    def list(
-            guild_id,
-            return_type
-    ):
+    def list(guild_id, return_type):
         ...
 
     @staticmethod
     @req('POST')
     def create(
-            guild_id,
-            user_id,
-            type,
+        guild_id,
+        user_id,
+        type,
     ):
         ...
 
     @staticmethod
     @req('POST')
     def delete(
-            guild_id,
-            user_id,
-            type,
+        guild_id,
+        user_id,
+        type,
     ):
         ...
 
@@ -124,43 +116,34 @@ class Channel:
 
     @staticmethod
     @req('GET')
-    def list(
-            guild_id
-    ):
+    def list(guild_id):
         ...
 
     @staticmethod
     @req('GET')
-    def view(
-            target_id
-    ):
+    def view(target_id):
         ...
 
     @staticmethod
     @req('POST')
     def create(
-            guild_id,
-            parent_id,
-            name,
-            type,
-            limit_amount,
-            voice_quality,
+        guild_id,
+        parent_id,
+        name,
+        type,
+        limit_amount,
+        voice_quality,
     ):
         ...
 
     @staticmethod
     @req('POST')
-    def delete(
-            channel_id
-    ):
+    def delete(channel_id):
         ...
 
     @staticmethod
     @req('POST')
-    def moveUser(
-            target_id,
-            user_ids
-    ):
+    def moveUser(target_id, user_ids):
         ...
 
 
@@ -168,37 +151,35 @@ class ChannelRole:
 
     @staticmethod
     @req('GET')
-    def index(
-            channel_id
-    ):
+    def index(channel_id):
         ...
 
     @staticmethod
     @req('POST')
     def create(
-            channel_id,
-            type,
-            value,
+        channel_id,
+        type,
+        value,
     ):
         ...
 
     @staticmethod
     @req('POST')
     def update(
-            channel_id,
-            type,
-            value,
-            allow,
-            deny,
+        channel_id,
+        type,
+        value,
+        allow,
+        deny,
     ):
         ...
 
     @staticmethod
     @req('POST')
     def delete(
-            channel_id,
-            type,
-            value,
+        channel_id,
+        type,
+        value,
     ):
         ...
 
@@ -207,89 +188,69 @@ class Message:
 
     @staticmethod
     @req('GET')
-    def view(
-            msg_id
-    ):
+    def view(msg_id):
         ...
 
     @staticmethod
     @req('GET')
     def list(
-            target_id,
-            msg_id,
-            pin,
-            flag,
+        target_id,
+        msg_id,
+        pin,
+        flag,
     ):
         ...
 
     @staticmethod
     @req('POST')
     def create(
-            type,
-            target_id,
-            content,
-            quote,
-            nonce,
-            temp_target_id,
+        type,
+        target_id,
+        content,
+        quote,
+        nonce,
+        temp_target_id,
     ):
         ...
 
     @staticmethod
     @req('POST')
     def update(
-            msg_id,
-            content,
-            quote,
-            temp_target_id,
+        msg_id,
+        content,
+        quote,
+        temp_target_id,
     ):
         ...
 
     @staticmethod
     @req('POST')
-    def delete(
-            msg_id,
-    ):
+    def delete(msg_id, ):
         ...
 
     @staticmethod
     @req('GET')
-    def reactionList(
-            msg_id,
-            emoji
-    ):
+    def reactionList(msg_id, emoji):
         ...
 
     @staticmethod
     @req('POST')
-    def addReaction(
-            msg_id,
-            emoji
-    ):
+    def addReaction(msg_id, emoji):
         ...
 
     @staticmethod
     @req('POST')
-    def deleteReaction(
-            msg_id,
-            emoji,
-            user_id
-    ):
+    def deleteReaction(msg_id, emoji, user_id):
         ...
 
     @staticmethod
     @req('POST')
-    def addReaction(
-            msg_id,
-            emoji
-    ):
+    def addReaction(msg_id, emoji):
         ...
 
     @staticmethod
     @req('POST')
-    def addReaction(
-            msg_id,
-            emoji
-    ):
+    def addReaction(msg_id, emoji):
         ...
 
 
@@ -297,29 +258,22 @@ class UserChat:
 
     @staticmethod
     @req('GET')
-    def list(
-    ):
+    def list():
         ...
 
     @staticmethod
     @req('GET')
-    def view(
-            chat_code
-    ):
+    def view(chat_code):
         ...
 
     @staticmethod
     @req('POST')
-    def create(
-            target_id
-    ):
+    def create(target_id):
         ...
 
     @staticmethod
     @req('POST')
-    def delete(
-            chat_code
-    ):
+    def delete(chat_code):
         ...
 
 
@@ -328,63 +282,52 @@ class DirectMessage:
     @staticmethod
     @req('GET')
     def list(
-            chat_code,
-            target_id,
-            msg_id,
-            flag,
+        chat_code,
+        target_id,
+        msg_id,
+        flag,
     ):
         ...
 
     @staticmethod
     @req('POST')
     def create(
-            type,
-            target_id,
-            chat_code,
-            content,
-            quote,
-            nonce,
+        type,
+        target_id,
+        chat_code,
+        content,
+        quote,
+        nonce,
     ):
         ...
 
     @staticmethod
     @req('POST')
     def update(
-            msg_id,
-            content,
-            quote,
+        msg_id,
+        content,
+        quote,
     ):
         ...
 
     @staticmethod
     @req('POST')
-    def delete(
-            msg_id
-    ):
+    def delete(msg_id):
         ...
 
     @staticmethod
     @req('GET')
-    def reactionList(
-            msg_id,
-            emoji
-    ):
+    def reactionList(msg_id, emoji):
         ...
 
     @staticmethod
     @req('POST')
-    def addReaction(
-            msg_id,
-            emoji
-    ):
+    def addReaction(msg_id, emoji):
         ...
 
     @staticmethod
     @req('POST')
-    def deleteReaction(
-            msg_id,
-            emoji
-    ):
+    def deleteReaction(msg_id, emoji):
         ...
 
 
@@ -392,9 +335,7 @@ class Gateway:
 
     @staticmethod
     @req('GET')
-    def index(
-            compress
-    ):
+    def index(compress):
         ...
 
 
@@ -402,15 +343,14 @@ class User:
 
     @staticmethod
     @req('GET')
-    def me(
-    ):
+    def me():
         ...
 
     @staticmethod
     @req('GET')
     def view(
-            user_id,
-            guild_id,
+        user_id,
+        guild_id,
     ):
         ...
 
@@ -419,9 +359,7 @@ class Asset:
 
     @staticmethod
     @req('POST')
-    def create(
-            file
-    ):
+    def create(file):
         ...
 
 
@@ -429,55 +367,53 @@ class GuildRole:
 
     @staticmethod
     @req('GET')
-    def list(
-            guild_id
-    ):
+    def list(guild_id):
         ...
 
     @staticmethod
     @req('POST')
     def create(
-            name,
-            guild_id,
+        name,
+        guild_id,
     ):
         ...
 
     @staticmethod
     @req('POST')
     def update(
-            guild_id,
-            role_id,
-            hoist,
-            mentionable,
-            permissions,
-            color,
-            name,
+        guild_id,
+        role_id,
+        hoist,
+        mentionable,
+        permissions,
+        color,
+        name,
     ):
         ...
 
     @staticmethod
     @req('POST')
     def delete(
-            guild_id,
-            role_id,
+        guild_id,
+        role_id,
     ):
         ...
 
     @staticmethod
     @req('POST')
     def grant(
-            guild_id,
-            user_id,
-            role_id,
+        guild_id,
+        user_id,
+        role_id,
     ):
         ...
 
     @staticmethod
     @req('POST')
     def revoke(
-            guild_id,
-            user_id,
-            role_id,
+        guild_id,
+        user_id,
+        role_id,
     ):
         ...
 
@@ -486,18 +422,16 @@ class Intimacy:
 
     @staticmethod
     @req('GET')
-    def index(
-            user_id
-    ):
+    def index(user_id):
         ...
 
     @staticmethod
     @req('POST')
     def update(
-            user_id,
-            score,
-            social_info,
-            img_id,
+        user_id,
+        score,
+        social_info,
+        img_id,
     ):
         ...
 
@@ -506,33 +440,29 @@ class GuildEmoji:
 
     @staticmethod
     @req('GET')
-    def list(
-            guild_id
-    ):
+    def list(guild_id):
         ...
 
     @staticmethod
     @req('POST', headers={'Content-Type': 'multipart/form-data'})
     def create(
-            name,
-            guild_id,
-            emoji,
+        name,
+        guild_id,
+        emoji,
     ):
         ...
 
     @staticmethod
     @req('POST')
     def update(
-            name,
-            id,
+        name,
+        id,
     ):
         ...
 
     @staticmethod
     @req('POST')
-    def delete(
-            id
-    ):
+    def delete(id):
         ...
 
 
@@ -541,24 +471,24 @@ class Invite:
     @staticmethod
     @req('GET')
     def list(
-            guild_id,
-            channel_id,
+        guild_id,
+        channel_id,
     ):
         ...
 
     @staticmethod
     @req('POST')
     def create(
-            guild_id,
-            channel_id,
+        guild_id,
+        channel_id,
     ):
         ...
 
     @staticmethod
     @req('POST')
     def delete(
-            guild_id,
-            channel_id,
-            url_code,
+        guild_id,
+        channel_id,
+        url_code,
     ):
         ...
