@@ -1,7 +1,7 @@
 import asyncio
 import inspect
 import logging
-from typing import Dict, List, Callable, Coroutine
+from typing import Dict, List, Callable, Coroutine, Union
 
 from . import api
 from .channel import public_channel_factory, PublicChannel
@@ -13,7 +13,7 @@ from .user import User
 
 log = logging.getLogger(__name__)
 
-TypeHandler = Callable[..., Coroutine]
+TypeHandler = Callable[[Union['Message', 'Event']], Coroutine]
 
 
 class Client(Requestable, AsyncRunnable):
@@ -118,11 +118,31 @@ class Client(Requestable, AsyncRunnable):
             self._me = User(_gate_=self.gate, _lazy_loaded_=True, **(await self.gate.exec_req(api.User.me())))
         return self._me
 
+    @property
+    def me(self) -> User:
+        """
+        get client itself corresponding User
+
+        RECOMMEND: use ``await fetch_me()``
+
+        CAUTION: please call ``await fetch_me()`` first to load data from khl server
+
+        designed as 'empty-then-fetch' will break the rule 'net-related is async'
+
+        :return: the client's underlying User
+        """
+        if self._me and self._me.is_loaded():
+            return self._me
+        raise ValueError('not loaded, please call `await fetch_me()` first')
+
     async def fetch_public_channel(self, channel_id: str) -> PublicChannel:
         """fetch details of a public channel from khl"""
         channel_data = await self.gate.exec_req(api.Channel.view(channel_id))
         return public_channel_factory(_gate_=self.gate, **channel_data)
 
+    async def delete_channel(self, channel_id: str):
+        return await self.gate.exec_req(api.Channel.delete(channel_id))
+
     async def list_guild(self) -> List[Guild]:
         """list guilds which the client joined"""
         guilds_data = (await self.gate.exec_pagination_req(api.Guild.list()))
