@@ -6,17 +6,17 @@ from aiohttp import ClientSession
 
 from .api import _Req
 from .cert import Cert
-from .interface import AsyncRunnable
 
 log = logging.getLogger(__name__)
 
 API = f'https://www.kaiheila.cn/api/v3'
 
 
-class HTTPRequester(AsyncRunnable):
+class HTTPRequester:
+
     def __init__(self, cert: Cert):
         self._cert = cert
-        self._cs: ClientSession = ClientSession(loop=self.loop)
+        self._cs: ClientSession = ClientSession()
 
     def __del__(self):
         asyncio.get_event_loop().run_until_complete(self._cs.close())
@@ -38,8 +38,13 @@ class HTTPRequester(AsyncRunnable):
     async def exec_req(self, r: _Req):
         return await self.request(r.method, r.route, **r.params)
 
-    async def exec_pagination_req(self, r: _Req, *, begin_page: int = 1, end_page: int = None,
-                                  page_size: int = 50, sort: str = '') -> List:
+    async def exec_pagination_req(self,
+                                  r: _Req,
+                                  *,
+                                  begin_page: int = 1,
+                                  end_page: int = None,
+                                  page_size: int = 50,
+                                  sort: str = '') -> List:
         """
         exec pagination requests, iter from ``begin_page`` to the ``end_page``, ``end_page=None`` means to the end
 
@@ -69,6 +74,7 @@ class HTTPRequester(AsyncRunnable):
         return ret
 
     class APIRequestFailed(Exception):
+
         def __init__(self, method, route, params, err_code, err_message):
             self.method = method
             self.route = route
